package com.up.sell.interceptor;

import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.Ordered;
import org.springframework.stereotype.Component;

import com.up.sell.service.SchedulerSwitchService;
import com.up.sell.vo.SchedulerSwitch;

@Component
@Aspect
public class SchedulerAspect implements Ordered {

	private static final Logger logger = LoggerFactory.getLogger(SchedulerAspect.class);
	
	@Autowired
	private SchedulerSwitchService schedulerSwitchService;
	
	@Around("@annotation(com.up.sell.annotation.SchedulerSwith)")
	public void schedulerSwitch(ProceedingJoinPoint pjp) throws Throwable {
		String methodName = pjp.getSignature().getName();
		logger.info("methodName : "+methodName);
		SchedulerSwitch schedSwitch = schedulerSwitchService.selectOneByMethodName(methodName);
		if(schedSwitch == null || schedSwitch.getStatus() == 0) {
			logger.info("方法被阻止运行……");
		}else {
			pjp.proceed();
			logger.info("方法被放行了……");
		}
	}
	
	
	
	@Override
	public int getOrder() {
		// TODO Auto-generated method stub
		return 0;
	}

}
